@@ -1,4 +1,4 @@
--- $Id: stored.sql 43094 2015-03-20 11:36:13Z cgielen $
+-- $Id: stored.sql 46588 2017-05-09 10:05:37Z wsl $
 -- $URL: https://svn.uvt.nl/its-id/trunk/sources/kiki/doc/stored.sql $
 
 \encoding UTF8
@@ -245,12 +245,12 @@ CREATE OR REPLACE FUNCTION upgrade_to_personal(ianr BIGINT, ialias BIGINT) RETUR
 	BEGIN
 		n := address FROM mail_addresses WHERE mail_alias = ialias;
 		IF EXISTS(SELECT * FROM internal_destinations WHERE mail_alias = ialias) THEN
-			RAISE EXCEPTION 'Poging om % te registreren voor % maar deze bestaat al als functioneel alias', n, a;
+			RAISE EXCEPTION 'Poging om % te registreren voor % maar deze bestaat al als functioneel alias', n, ianr;
 		END IF;
 		p := COUNT(*) FROM personal_destinations WHERE mail_alias = ialias;
 		e := COUNT(*) FROM external_destinations WHERE mail_alias = ialias;
 		IF p + e > 1 THEN
-			RAISE EXCEPTION 'Poging om % te registreren voor % maar deze bestaat al als functioneel alias', n, a;
+			RAISE EXCEPTION 'Poging om % te registreren voor % maar deze bestaat al als functioneel alias', n, ianr;
 		ELSIF p = 1 THEN
 			SELECT INTO p person FROM persons JOIN personal_destinations USING (person) WHERE mail_alias = ialias;
 			IF p <> ianr THEN
@@ -273,28 +273,29 @@ CREATE OR REPLACE FUNCTION upgrade_to_personal(ianr BIGINT, ialias BIGINT) RETUR
 		-- internal_destinations mogen niet wijzen naar een mail_alias met ingevulde person
 		FOR e IN DELETE FROM internal_destinations WHERE destination = ialias RETURNING mail_alias
 		LOOP
-			INSERT INTO personal_destinations (mail_alias, person) VALUES (a, ianr);
+			INSERT INTO personal_destinations (mail_alias, person) VALUES (e, ianr);
 		END LOOP;
 	END;
 $$ LANGUAGE plpgsql;
 
-CREATE OR REPLACE FUNCTION force_to_personal(iperson BIGINT, ialias BIGINT) RETURNS VOID AS $$
+CREATE OR REPLACE FUNCTION force_to_personal(ianr BIGINT, ialias BIGINT) RETURNS VOID AS $$
 	DECLARE
-		n TEXT;
-		m TEXT;
-		d TEXT;
-		p BIGINT;
 		e BIGINT;
-		a BIGINT;
 	BEGIN
 		UPDATE mail_aliases SET addressbook = FALSE WHERE mail_alias = ialias;
 		DELETE FROM internal_destinations WHERE mail_alias = ialias;
 		DELETE FROM external_destinations WHERE mail_alias = ialias;
-		DELETE FROM personal_destinations WHERE mail_alias = ialias AND person <> iperson;
-		IF NOT EXISTS(SELECT * FROM personal_destinations WHERE mail_alias = ialias AND person = iperson) THEN
-			INSERT INTO personal_destinations (mail_alias, person) VALUES (ialias, iperson);
+		DELETE FROM personal_destinations WHERE mail_alias = ialias AND person <> ianr;
+		IF NOT EXISTS(SELECT * FROM personal_destinations WHERE mail_alias = ialias AND person = ianr) THEN
+			INSERT INTO personal_destinations (mail_alias, person) VALUES (ialias, ianr);
 		END IF;
-		UPDATE mail_aliases SET person = iperson WHERE mail_alias = ialias;
+		UPDATE mail_aliases SET person = ianr WHERE mail_alias = ialias;
+
+		-- internal_destinations mogen niet wijzen naar een mail_alias met ingevulde person
+		FOR e IN DELETE FROM internal_destinations WHERE destination = ialias RETURNING mail_alias
+		LOOP
+			INSERT INTO personal_destinations (mail_alias, person) VALUES (e, ianr);
+		END LOOP;
 	END;
 $$ LANGUAGE plpgsql;
 
