@@ -20,14 +20,16 @@ field session_data => sub {
 
 field session => sub {
 	my $self = shift;
-	return $self->cur_session
-		|| $self->crypto->create_token($self->session_data);
+	my $cur_session = $self->cur_session;
+	return $cur_session if $cur_session;
+	my (undef, undef, $token) = $self->crypto->create_token($self->session_data);
+	return $token;
 };
 
 field cur_session => sub {
 	my $self = shift;
 	my $token = $self->cookie('session');
-	return scalar eval { $self->crypto->check_token($self->session_data, $token); $token };
+	return eval { $self->crypto->check_token($self->session_data, $token); $token };
 };
 
 field authorized => sub {
@@ -49,5 +51,6 @@ param nonce => sub {
 };
 
 sub create_nonce {
-	return scalar $self->crypto->create_token('n'.$self->session);
+	my (undef, undef, $token) = $self->crypto->create_token('n'.$self->session);
+	return $token;
 }
